# eric7.QScintilla.DocstringGenerator.__init__

Package containing the documentation string generator tool.

### Global Attributes

None

### Classes

None

### Functions

getDocstringGenerator | Function to get a docstring generator for the given editor.
getSupportedDocstringTypes | Function to get the supported docstring types/styles.

## getDocstringGenerator

getDocstringGenerator(editor)

Function to get a docstring generator for the given editor.

editor (Editor)
  reference to the editor to create a docstring generator for

Return:
  reference to the created docstring generator

Return Type:
  BaseDocstringGenerator

Up

## getSupportedDocstringTypes

getSupportedDocstringTypes()

Function to get the supported docstring types/styles.

Return:
  list of tuples with supported docstring type/style and the corresponding display string

Return Type:
  tuple of (str, str)

Up